Re-land "[shill] Get rid of Entry as a first-class citizen""

This reverts commit 7c1ab1cb74bf6397c67e1cdc825043a93c4bce33.

Also, fixes some compile problems that only repro with debug flags
and that cause runtime dbus errors with the new version of libdbus

BUG=chromium-os:17436
TEST=unit tests

Change-Id: I479308e684b802f167788daeaf4ec39d0b63ee17
Reviewed-on: http://gerrit.chromium.org/gerrit/3961
Tested-by: Chris Masone <cmasone@chromium.org>
Reviewed-by: Darin Petkov <petkov@chromium.org>
diff --git a/profile.h b/profile.h
index 8951474..8b18103 100644
--- a/profile.h
+++ b/profile.h
@@ -43,10 +43,10 @@
 
   PropertyStore *store() { return &store_; }
 
-  // Begin managing the persistence of |entry|, addressable by |entry_name|.
-  void AdoptEntry(const std::string &entry_name, const EntryRefPtr &entry);
+  // Begin managing the persistence of |service|, addressable by |name|.
+  void AdoptService(const std::string &name, const ServiceRefPtr &service);
 
-  virtual bool MoveToActiveProfile(const std::string &entry_name) {
+  virtual bool MoveToActiveProfile(const std::string &name) {
     return false;
   }
 
@@ -74,14 +74,14 @@
 
   // Entries representing services that are persisted to disk.
   // A std::map because we will need random access for GetEntry(), but usually
-  // will want to iterate over all Entries.
-  std::map<std::string, EntryRefPtr> entries_;
+  // will want to iterate over all Services.
+  std::map<std::string, ServiceRefPtr> services_;
 
  private:
   friend class ProfileAdaptorInterface;
   FRIEND_TEST(ProfileTest, IsValidIdentifierToken);
-  // TODO(cmasone): once we can add entries organically, take this out.
-  FRIEND_TEST(ServiceTest, MoveEntry);
+  // TODO(cmasone): once we can add services organically, take this out.
+  FRIEND_TEST(ServiceTest, MoveService);
 
   static bool IsValidIdentifierToken(const std::string &token);